**Note**: *Many endpoints have not been implemented yet, but will be soon.*

lithon
=============

.. image:: https://img.shields.io/github/license/Infiniticity/lithon
    :target: https://github.com/Infiniticity/lithon/blob/main/LICENSE
    :alt: license
.. image:: https://img.shields.io/tokei/lines/github/Infiniticity/lithon
    :target: https://github.com/Infiniticity/lithon/graphs/contributors
    :alt: lines of code
.. image:: https://img.shields.io/pypi/v/lithon
    :target: https://pypi.python.org/pypi/lithon
    :alt: PyPI version info
.. image:: https://img.shields.io/pypi/pyversions/lithon
    :alt: Python version info

Lichess is a free, libre, adless, open-source chess server, and lithon (`li[chess in py]thon <https://github.com/lichess-org/lila#:~:text=Lila%20(li%5Bchess%20in%20sca%5Dla)>`_) is a Python API wrapper for the Lichess API.


Key Features
------------
- Modern Pythonic interface with an object-oriented approach.
- Proper JSON, NDJSON and exception handling.
- Optimised in both, speed and memory.


Installation
------------

**Python 3.8 or higher is required.**

To install the stable version, do the following:

.. code-block:: sh

    # Unix / macOS
    python3 -m pip install "lithon"

    # Windows
    py -m pip install "lithon"


To install the development version, do the following:

.. code-block:: sh

    $ git clone https://github.com/Infiniticity/lithon


Links
-----

- `Lichess <https://lichess.org/>`_
- `Documentation <https://lichess.readthedocs.io/>`_
